lambdaisland.cli.cmdspec

Some of the command spec parsing extracted so it can be reused in lambdaisland.cli.completions

Some of the command spec parsing extracted so it can be reused in
lambdaisland.cli.completions
raw docstring

add-processed-flagsclj

(add-processed-flags cmdspec extra-flags)

We process flag information for easier use, this results in :flagpairs (ordered sequence of pairs, mainly used in printing help information), and :flagmap (for easy lookup), added to the cmdspec. As we process arguments we may need to add additional flags, based on the current subcommand. This function is used both for the top-level as for subcommand handling of flags.

We process flag information for easier use, this results in
`:flagpairs` (ordered sequence of pairs, mainly used in printing help
information), and `:flagmap` (for easy lookup), added to the `cmdspec`. As we
process arguments we may need to add additional flags, based on the current
subcommand. This function is used both for the top-level as for subcommand
handling of flags.
sourceraw docstring

args-reclj

source

build-flagmap-entriesclj

(build-flagmap-entries [flagstr flagopts])
source

cmd->flagsclj

(cmd->flags cmdspec args)
source

coerce-to-pairsclj

(coerce-to-pairs o)
source

flag-reclj

source

parse-arg-namesclj

(parse-arg-names str)
source

parse-flagstrclj

(parse-flagstr flagstr flagopts)
source

parse-flagstrsclj

(parse-flagstrs flagpairs)
source

prepare-cmdpairsclj

(prepare-cmdpairs commands)
source

prepare-flagpairsclj

(prepare-flagpairs flagstrs)
source

to-cmdspecclj

(to-cmdspec ?var)
source

cljdoc builds & hosts documentation for Clojure/Script libraries