Some of the command spec parsing extracted so it can be reused in lambdaisland.cli.completions
Some of the command spec parsing extracted so it can be reused in lambdaisland.cli.completions
(add-processed-flags cmdspec extra-flags)We process flag information for easier use, this results in
:flagpairs (ordered sequence of pairs, mainly used in printing help
information), and :flagmap (for easy lookup), added to the cmdspec. As we
process arguments we may need to add additional flags, based on the current
subcommand. This function is used both for the top-level as for subcommand
handling of flags.
We process flag information for easier use, this results in `:flagpairs` (ordered sequence of pairs, mainly used in printing help information), and `:flagmap` (for easy lookup), added to the `cmdspec`. As we process arguments we may need to add additional flags, based on the current subcommand. This function is used both for the top-level as for subcommand handling of flags.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |